diff --git a/gatt_cache_manager.c b/gatt_cache_manager.c
index 9e4677c..e78a693 100644
--- a/gatt_cache_manager.c
+++ b/gatt_cache_manager.c
@@ -284,6 +284,44 @@ static bool local_db_update_in_evt(uint16_t conn_handle)
     return success;
 }
 
+/**@brief Function for checking if local db is up to date.
+ *
+ * @param[in]  conn_handle  The connection to check.
+ *
+ * @return Return whether local db needs to be updated or not.
+ */
+
+static bool local_db_needs_update(uint16_t conn_handle)
+{
+    ret_code_t err_code;
+    pm_peer_data_flash_t peer_data;
+    bool needs_update = true;
+    uint16_t len;
+
+
+    err_code = pdb_peer_data_ptr_get(im_peer_id_get_by_conn_handle(conn_handle),
+                                  PM_PEER_DATA_ID_GATT_LOCAL,
+                                  &peer_data);
+    ASSERT(err_code == NRF_SUCCESS);
+
+    len = peer_data.p_local_gatt_db->len;
+
+    uint8_t sys_attr_data[len];
+    
+    err_code = sd_ble_gatts_sys_attr_get(conn_handle, sys_attr_data, &len,
+                                         peer_data.p_local_gatt_db->flags);
+    
+    ASSERT(err_code == NRF_SUCCESS);
+
+    if(memcmp(sys_attr_data, &peer_data.p_local_gatt_db->data, len) == 0)
+    {
+        NRF_LOG_DEBUG("Local db is up to date");
+        needs_update = false;
+    }
+
+   return needs_update;  
+}
+
 #if PM_SERVICE_CHANGED_ENABLED
 
 /**@brief Function for getting the value of the CCCD for the service changed characteristic.
@@ -702,13 +740,16 @@ void gcm_ble_evt_handler(ble_evt_t const * p_ble_evt)
 #endif
 
         case BLE_GATTS_EVT_WRITE:
-            if (cccd_written(&p_ble_evt->evt.gatts_evt.params.write))
+        {
+            /* Skip local db update if new CCCD setting is identical to the previous one */
+            if (cccd_written(&p_ble_evt->evt.gatts_evt.params.write) &&
+               (local_db_needs_update(conn_handle))) 
             {
                 local_db_update(conn_handle, true);
                 update_pending_flags_check();
             }
             break;
-
+        }
         case BLE_GATTC_EVT_CHAR_VAL_BY_UUID_READ_RSP:
         {
             bool handle_found = false;
